/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <pysideqenum.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <iterator>

// module include
#include "pyside2_qt3dcore_python.h"

// main header
#include "qt3dcore_qstaticpropertyvalueaddedchangebase_wrapper.h"

// inner classes

#include <cctype>
#include <cstring>



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QStaticPropertyValueAddedChangeBaseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QStaticPropertyValueAddedChangeBaseWrapper::QStaticPropertyValueAddedChangeBaseWrapper(Qt3DCore::QNodeId subjectId) : Qt3DCore::QStaticPropertyValueAddedChangeBase(subjectId)
{
    resetPyMethodCache();
    // ... middle
}

QStaticPropertyValueAddedChangeBaseWrapper::~QStaticPropertyValueAddedChangeBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DCore::QStaticPropertyValueAddedChangeBase >()))
        return -1;

    ::QStaticPropertyValueAddedChangeBaseWrapper *cptr{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase.__init__";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStaticPropertyValueAddedChangeBase", 1, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStaticPropertyValueAddedChangeBase::QStaticPropertyValueAddedChangeBase(Qt3DCore::QNodeId)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppValueConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QNODEID_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QStaticPropertyValueAddedChangeBase(Qt3DCore::QNodeId)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Init_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNodeId cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QStaticPropertyValueAddedChangeBase(Qt3DCore::QNodeId)
            cptr = new ::QStaticPropertyValueAddedChangeBaseWrapper(cppArg0);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DCore::QStaticPropertyValueAddedChangeBase >(), cptr)) {
        delete cptr;
        Py_XDECREF(errInfo);
        return -1;
    }
    if (!cptr) goto Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, fullName, errInfo);
        Py_XDECREF(errInfo);
        return -1;
}

static PyObject *Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_propertyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase.propertyName";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // propertyName()const
            const char * cppResult = const_cast<const ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(cppSelf)->propertyName();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_setPropertyName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase.setPropertyName";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStaticPropertyValueAddedChangeBase::setPropertyName(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // setPropertyName(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_setPropertyName_TypeError;

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPropertyName(const char*)
            cppSelf->setPropertyName(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_setPropertyName_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}


static const char *Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_methods[] = {
    {"propertyName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_propertyName), METH_NOARGS},
    {"setPropertyName", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBaseFunc_setPropertyName), METH_O},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QStaticPropertyValueAddedChangeBaseWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Type = nullptr;
static SbkObjectType *Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF(void)
{
    return _Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Type;
}

static PyType_Slot Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_spec = {
    "2:PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_slots
};

} //extern "C"

static void *Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::Qt3DCore::QSceneChange >()))
        return dynamic_cast< ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(reinterpret_cast< ::Qt3DCore::QSceneChange *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStaticPropertyValueAddedChangeBase_PythonToCpp_QStaticPropertyValueAddedChangeBase_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStaticPropertyValueAddedChangeBase_PythonToCpp_QStaticPropertyValueAddedChangeBase_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF())))
        return QStaticPropertyValueAddedChangeBase_PythonToCpp_QStaticPropertyValueAddedChangeBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStaticPropertyValueAddedChangeBase_PTR_CppToPython_QStaticPropertyValueAddedChangeBase(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::Qt3DCore::QStaticPropertyValueAddedChangeBase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DCore_QStaticPropertyValueAddedChangeBase_SignatureStrings[] = {
    "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase(self,subjectId:PySide2.Qt3DCore.Qt3DCore.QNodeId)",
    "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase.propertyName(self)->char*",
    "PySide2.Qt3DCore.Qt3DCore.QStaticPropertyValueAddedChangeBase.setPropertyName(self,name:char*)",
    nullptr}; // Sentinel

void init_Qt3DCore_QStaticPropertyValueAddedChangeBase(PyObject *enclosingClass)
{
    _Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QStaticPropertyValueAddedChangeBase",
        "Qt3DCore::QStaticPropertyValueAddedChangeBase*",
        &Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_spec,
        &Shiboken::callCppDestructor< ::Qt3DCore::QStaticPropertyValueAddedChangeBase >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QPROPERTYVALUEADDEDCHANGEBASE_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass    );
    
    auto pyType = reinterpret_cast<PyTypeObject *>(_Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Type);
    InitSignatureStrings(pyType, Qt3DCore_QStaticPropertyValueAddedChangeBase_SignatureStrings);
    SbkObjectType_SetPropertyStrings(reinterpret_cast<PyTypeObject *>(_Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_Type), Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_PropertyStrings);
    SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF(),
        QStaticPropertyValueAddedChangeBase_PythonToCpp_QStaticPropertyValueAddedChangeBase_PTR,
        is_QStaticPropertyValueAddedChangeBase_PythonToCpp_QStaticPropertyValueAddedChangeBase_PTR_Convertible,
        QStaticPropertyValueAddedChangeBase_PTR_CppToPython_QStaticPropertyValueAddedChangeBase);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QStaticPropertyValueAddedChangeBase");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QStaticPropertyValueAddedChangeBase*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QStaticPropertyValueAddedChangeBase&");
    Shiboken::Conversions::registerConverterName(converter, "QStaticPropertyValueAddedChangeBase");
    Shiboken::Conversions::registerConverterName(converter, "QStaticPropertyValueAddedChangeBase*");
    Shiboken::Conversions::registerConverterName(converter, "QStaticPropertyValueAddedChangeBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QStaticPropertyValueAddedChangeBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStaticPropertyValueAddedChangeBaseWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_TypeF(), &Sbk_Qt3DCore_QStaticPropertyValueAddedChangeBase_typeDiscovery);

}
