/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <pysideqenum.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <iterator>

// module include
#include "pyside2_qtgui_python.h"

// main header
#include "qopenglfunctions_wrapper.h"

// inner classes

// Extra includes
#include <QtGui/qopenglcontext.h>


#include <cctype>
#include <cstring>



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLFunctions_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLFunctions >()))
        return -1;

    ::QOpenGLFunctions *cptr{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.__init__";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QOpenGLFunctions", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLFunctions::QOpenGLFunctions()
    // 1: QOpenGLFunctions::QOpenGLFunctions(QOpenGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLFunctions()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QOPENGLCONTEXT_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOpenGLFunctions(QOpenGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QOpenGLFunctions_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLFunctions()
        {

            if (!PyErr_Occurred()) {
                // QOpenGLFunctions()
                cptr = new ::QOpenGLFunctions();
            }
            break;
        }
        case 1: // QOpenGLFunctions(QOpenGLContext * context)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLContext *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // QOpenGLFunctions(QOpenGLContext*)
                cptr = new ::QOpenGLFunctions(cppArg0);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLFunctions >(), cptr)) {
        delete cptr;
        Py_XDECREF(errInfo);
        return -1;
    }
    if (!cptr) goto Sbk_QOpenGLFunctions_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QOpenGLFunctions_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, fullName, errInfo);
        Py_XDECREF(errInfo);
        return -1;
}

static PyObject *Sbk_QOpenGLFunctionsFunc_glFinish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.glFinish";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // glFinish()
            cppSelf->glFinish();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctionsFunc_glFlush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.glFlush";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // glFlush()
            cppSelf->glFlush();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctionsFunc_glGetShaderSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.glGetShaderSource";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions::glGetShaderSource(uint)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // glGetShaderSource(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QOpenGLFunctionsFunc_glGetShaderSource_TypeError;

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (!PyErr_Occurred()) {
            // glGetShaderSource(uint)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (glgetshadersource)]
            GLsizei bufSize = 4096;
            GLsizei length = bufSize - 1;
            QByteArray buffer;
            for (; length == bufSize - 1; bufSize += 4096) {
                buffer.resize(qsizetype(bufSize));
                cppSelf->glGetShaderSource(cppArg0, bufSize, &length, buffer.data());
                if (cppSelf->glGetError() != GL_NO_ERROR) {
                    buffer.clear();
                    break;
                }
            }
            auto *data = buffer.constData();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data);
            // END of custom code block [file: ../glue/qtgui.cpp (glgetshadersource)]
            // ========================================================================

            // End of code injection

        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QOpenGLFunctionsFunc_glGetShaderSource_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QOpenGLFunctionsFunc_glReleaseShaderCompiler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.glReleaseShaderCompiler";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // glReleaseShaderCompiler()
            cppSelf->glReleaseShaderCompiler();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctionsFunc_glShaderSource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.glShaderSource";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "glShaderSource", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions::glShaderSource(uint,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // glShaderSource(uint,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QOpenGLFunctionsFunc_glShaderSource_TypeError;

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)

        if (!PyErr_Occurred()) {
            // glShaderSource(uint,QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (glshadersource)]
            const QByteArray buffer = cppArg1.toUtf8();
            const char *sources[] = {buffer.constData()};
            cppSelf->glShaderSource(cppArg0, 1, sources, nullptr);
            // END of custom code block [file: ../glue/qtgui.cpp (glshadersource)]
            // ========================================================================

            // End of code injection

        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QOpenGLFunctionsFunc_glShaderSource_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QOpenGLFunctionsFunc_hasOpenGLFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.hasOpenGLFeature";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions::hasOpenGLFeature(QOpenGLFunctions::OpenGLFeature)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, (pyArg)))) {
        overloadId = 0; // hasOpenGLFeature(QOpenGLFunctions::OpenGLFeature)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QOpenGLFunctionsFunc_hasOpenGLFeature_TypeError;

    // Call function/method
    {
        ::QOpenGLFunctions::OpenGLFeature cppArg0 = static_cast< ::QOpenGLFunctions::OpenGLFeature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // hasOpenGLFeature(QOpenGLFunctions::OpenGLFeature)const
            bool cppResult = const_cast<const ::QOpenGLFunctions *>(cppSelf)->hasOpenGLFeature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QOpenGLFunctionsFunc_hasOpenGLFeature_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}

static PyObject *Sbk_QOpenGLFunctionsFunc_initializeOpenGLFunctions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.initializeOpenGLFunctions";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // initializeOpenGLFunctions()
            cppSelf->initializeOpenGLFunctions();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctionsFunc_openGLFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QOpenGLFunctions *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtGui.QOpenGLFunctions.openGLFeatures";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // openGLFeatures()const
            QFlags<QOpenGLFunctions::OpenGLFeature> cppResult = const_cast<const ::QOpenGLFunctions *>(cppSelf)->openGLFeatures();
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLFunctions_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLFunctions_methods[] = {
    {"glFinish", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_glFinish), METH_NOARGS},
    {"glFlush", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_glFlush), METH_NOARGS},
    {"glGetShaderSource", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_glGetShaderSource), METH_O},
    {"glReleaseShaderCompiler", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_glReleaseShaderCompiler), METH_NOARGS},
    {"glShaderSource", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_glShaderSource), METH_VARARGS},
    {"hasOpenGLFeature", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_hasOpenGLFeature), METH_O},
    {"initializeOpenGLFunctions", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_initializeOpenGLFunctions), METH_NOARGS},
    {"openGLFeatures", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctionsFunc_openGLFeatures), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLFunctions_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QOpenGLFunctions_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QOpenGLFunctions_Type = nullptr;
static SbkObjectType *Sbk_QOpenGLFunctions_TypeF(void)
{
    return _Sbk_QOpenGLFunctions_Type;
}

static PyType_Slot Sbk_QOpenGLFunctions_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLFunctions_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLFunctions_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLFunctions_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLFunctions_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLFunctions_spec = {
    "2:PySide2.QtGui.QOpenGLFunctions",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLFunctions_slots
};

} //extern "C"

PyObject *SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___and__(PyObject *self, PyObject *pyArg)
{
    ::QOpenGLFunctions::OpenGLFeatures cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf & cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___or__(PyObject *self, PyObject *pyArg)
{
    ::QOpenGLFunctions::OpenGLFeatures cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf | cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___xor__(PyObject *self, PyObject *pyArg)
{
    ::QOpenGLFunctions::OpenGLFeatures cppResult, cppSelf, cppArg;
#ifdef IS_PY3K
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyLong_AsLong(pyArg)));
    if (PyErr_Occurred())
    return nullptr;
#else
    cppSelf = static_cast<::QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(self)));
    cppArg = static_cast<QOpenGLFunctions::OpenGLFeatures>(int(PyInt_AsLong(pyArg)));
#endif

    if (PyErr_Occurred())
        return nullptr;
    cppResult = cppSelf ^ cppArg;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, &cppResult);
}

PyObject *SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___invert__(PyObject *self, PyObject *pyArg)
{
    ::QOpenGLFunctions::OpenGLFeatures cppSelf;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, self, &cppSelf);
    ::QOpenGLFunctions::OpenGLFeatures cppResult = ~cppSelf;
    return Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, &cppResult);
}

static PyObject *SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_long(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, self, &val);
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &val);
}
static int SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature__nonzero(PyObject *self)
{
    int val;
    Shiboken::Conversions::pythonToCppCopy(*PepType_SGTP(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])->converter, self, &val);
    return val != 0;
}

static PyType_Slot SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_number_slots[] = {
#ifdef IS_PY3K
    {Py_nb_bool,    reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature__nonzero)},
#else
    {Py_nb_nonzero, reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature__nonzero)},
    {Py_nb_long,    reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_long)},
#endif
    {Py_nb_invert,  reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___invert__)},
    {Py_nb_and,     reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___and__)},
    {Py_nb_xor,     reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___xor__)},
    {Py_nb_or,      reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature___or__)},
    {Py_nb_int,     reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_long)},
    {Py_nb_index,   reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_long)},
#ifndef IS_PY3K
    {Py_nb_long,    reinterpret_cast<void *>(SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_long)},
#endif
    {0, nullptr} // sentinel
};



// Type conversion functions.

// Python to C++ enum conversion.
static void QOpenGLFunctions_OpenGLFeature_PythonToCpp_QOpenGLFunctions_OpenGLFeature(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QOpenGLFunctions::OpenGLFeature *>(cppOut) =
        static_cast<::QOpenGLFunctions::OpenGLFeature>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QOpenGLFunctions_OpenGLFeature_PythonToCpp_QOpenGLFunctions_OpenGLFeature_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]))
        return QOpenGLFunctions_OpenGLFeature_PythonToCpp_QOpenGLFunctions_OpenGLFeature;
    return {};
}
static PyObject *QOpenGLFunctions_OpenGLFeature_CppToPython_QOpenGLFunctions_OpenGLFeature(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLFunctions::OpenGLFeature *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX], castCppIn);

}

static void QFlags_QOpenGLFunctions_OpenGLFeature__PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QOpenGLFunctions::OpenGLFeature> *>(cppOut) =
        ::QFlags<QOpenGLFunctions::OpenGLFeature>(QFlag(int(PySide::QFlags::getValue(reinterpret_cast<PySideQFlagsObject *>(pyIn)))));

}
static PythonToCppFunc is_QFlags_QOpenGLFunctions_OpenGLFeature__PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]))
        return QFlags_QOpenGLFunctions_OpenGLFeature__PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_;
    return {};
}
static PyObject *QFlags_QOpenGLFunctions_OpenGLFeature__CppToPython_QFlags_QOpenGLFunctions_OpenGLFeature_(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QFlags<QOpenGLFunctions::OpenGLFeature> *>(cppIn));
    return reinterpret_cast<PyObject *>(PySide::QFlags::newObject(castCppIn, SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]));

}

static void QOpenGLFunctions_OpenGLFeature_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QFlags<QOpenGLFunctions::OpenGLFeature> *>(cppOut) =
        ::QFlags<QOpenGLFunctions::OpenGLFeature>(QFlag(int(Shiboken::Enum::getValue(pyIn))));

}
static PythonToCppFunc is_QOpenGLFunctions_OpenGLFeature_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]))
        return QOpenGLFunctions_OpenGLFeature_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_;
    return {};
}
static void number_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_(PyObject *pyIn, void *cppOut) {
    Shiboken::AutoDecRef pyLong(PyNumber_Long(pyIn));
    *reinterpret_cast<::QFlags<QOpenGLFunctions::OpenGLFeature> *>(cppOut) =
        ::QFlags<QOpenGLFunctions::OpenGLFeature>(QFlag(int(PyLong_AsLong(pyLong.object()))));

}
static PythonToCppFunc is_number_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible(PyObject *pyIn) {
    if (PyNumber_Check(pyIn) && PyObject_TypeCheck(pyIn, SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]))
        return number_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_;
    return {};
}
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLFunctions_PythonToCpp_QOpenGLFunctions_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLFunctions_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLFunctions_PythonToCpp_QOpenGLFunctions_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QOpenGLFunctions_TypeF())))
        return QOpenGLFunctions_PythonToCpp_QOpenGLFunctions_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLFunctions_PTR_CppToPython_QOpenGLFunctions(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::QOpenGLFunctions *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QOpenGLFunctions_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLFunctions_SignatureStrings[] = {
    "1:PySide2.QtGui.QOpenGLFunctions(self)",
    "0:PySide2.QtGui.QOpenGLFunctions(self,context:PySide2.QtGui.QOpenGLContext)",
    "PySide2.QtGui.QOpenGLFunctions.glFinish(self)",
    "PySide2.QtGui.QOpenGLFunctions.glFlush(self)",
    "PySide2.QtGui.QOpenGLFunctions.glGetShaderSource(self,shader:uint)->char*",
    "PySide2.QtGui.QOpenGLFunctions.glReleaseShaderCompiler(self)",
    "PySide2.QtGui.QOpenGLFunctions.glShaderSource(self,shader:uint,source:QString)",
    "PySide2.QtGui.QOpenGLFunctions.hasOpenGLFeature(self,feature:PySide2.QtGui.QOpenGLFunctions.OpenGLFeature)->bool",
    "PySide2.QtGui.QOpenGLFunctions.initializeOpenGLFunctions(self)",
    "PySide2.QtGui.QOpenGLFunctions.openGLFeatures(self)->PySide2.QtGui.QOpenGLFunctions.OpenGLFeatures",
    nullptr}; // Sentinel

void init_QOpenGLFunctions(PyObject *module)
{
    _Sbk_QOpenGLFunctions_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLFunctions",
        "QOpenGLFunctions*",
        &Sbk_QOpenGLFunctions_spec,
        &Shiboken::callCppDestructor< ::QOpenGLFunctions >,
        0,
        0,
        0    );
    
    auto pyType = reinterpret_cast<PyTypeObject *>(_Sbk_QOpenGLFunctions_Type);
    InitSignatureStrings(pyType, QOpenGLFunctions_SignatureStrings);
    SbkObjectType_SetPropertyStrings(reinterpret_cast<PyTypeObject *>(_Sbk_QOpenGLFunctions_Type), Sbk_QOpenGLFunctions_PropertyStrings);
    SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QOpenGLFunctions_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QOpenGLFunctions_TypeF(),
        QOpenGLFunctions_PythonToCpp_QOpenGLFunctions_PTR,
        is_QOpenGLFunctions_PythonToCpp_QOpenGLFunctions_PTR_Convertible,
        QOpenGLFunctions_PTR_CppToPython_QOpenGLFunctions);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLFunctions).name());


    // Initialization of enums.

    // Initialization of enum 'OpenGLFeature'.
    SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX] = PySide::QFlags::create("2:PySide2.QtGui.QOpenGLFunctions.OpenGLFeatures", SbkPySide2_QtGui_QOpenGLFunctions_OpenGLFeature_number_slots);
    SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QOpenGLFunctions_TypeF(),
        "OpenGLFeature",
        "2:PySide2.QtGui.QOpenGLFunctions.OpenGLFeature",
        "QOpenGLFunctions::OpenGLFeature",
        SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]);
    if (!SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "Multitexture", (long) QOpenGLFunctions::OpenGLFeature::Multitexture))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "Shaders", (long) QOpenGLFunctions::OpenGLFeature::Shaders))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "Buffers", (long) QOpenGLFunctions::OpenGLFeature::Buffers))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "Framebuffers", (long) QOpenGLFunctions::OpenGLFeature::Framebuffers))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendColor", (long) QOpenGLFunctions::OpenGLFeature::BlendColor))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendEquation", (long) QOpenGLFunctions::OpenGLFeature::BlendEquation))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendEquationSeparate", (long) QOpenGLFunctions::OpenGLFeature::BlendEquationSeparate))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendFuncSeparate", (long) QOpenGLFunctions::OpenGLFeature::BlendFuncSeparate))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendSubtract", (long) QOpenGLFunctions::OpenGLFeature::BlendSubtract))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "CompressedTextures", (long) QOpenGLFunctions::OpenGLFeature::CompressedTextures))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "Multisample", (long) QOpenGLFunctions::OpenGLFeature::Multisample))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "StencilSeparate", (long) QOpenGLFunctions::OpenGLFeature::StencilSeparate))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "NPOTTextures", (long) QOpenGLFunctions::OpenGLFeature::NPOTTextures))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "NPOTTextureRepeat", (long) QOpenGLFunctions::OpenGLFeature::NPOTTextureRepeat))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "FixedFunctionPipeline", (long) QOpenGLFunctions::OpenGLFeature::FixedFunctionPipeline))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "TextureRGFormats", (long) QOpenGLFunctions::OpenGLFeature::TextureRGFormats))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "MultipleRenderTargets", (long) QOpenGLFunctions::OpenGLFeature::MultipleRenderTargets))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
        Sbk_QOpenGLFunctions_TypeF(), "BlendEquationAdvanced", (long) QOpenGLFunctions::OpenGLFeature::BlendEquationAdvanced))
        return;
    // Register converter for enum 'QOpenGLFunctions::OpenGLFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
            QOpenGLFunctions_OpenGLFeature_CppToPython_QOpenGLFunctions_OpenGLFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLFunctions_OpenGLFeature_PythonToCpp_QOpenGLFunctions_OpenGLFeature,
            is_QOpenGLFunctions_OpenGLFeature_PythonToCpp_QOpenGLFunctions_OpenGLFeature_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions::OpenGLFeature");
        Shiboken::Conversions::registerConverterName(converter, "OpenGLFeature");
    }
    // Register converter for flag 'QFlags<QOpenGLFunctions::OpenGLFeature>'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX],
            QFlags_QOpenGLFunctions_OpenGLFeature__CppToPython_QFlags_QOpenGLFunctions_OpenGLFeature_);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLFunctions_OpenGLFeature_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_,
            is_QOpenGLFunctions_OpenGLFeature_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QFlags_QOpenGLFunctions_OpenGLFeature__PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_,
            is_QFlags_QOpenGLFunctions_OpenGLFeature__PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            number_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature_,
            is_number_PythonToCpp_QFlags_QOpenGLFunctions_OpenGLFeature__Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions::OpenGLFeatures");
        Shiboken::Conversions::registerConverterName(converter, "OpenGLFeatures");
    }
    // End of 'OpenGLFeature' enum/flags.

    qRegisterMetaType< ::QOpenGLFunctions::OpenGLFeature >("QOpenGLFunctions::OpenGLFeature");
    qRegisterMetaType< ::QOpenGLFunctions::OpenGLFeatures >("QOpenGLFunctions::OpenGLFeatures");
}
