/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <pysideqenum.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <iterator>

// module include
#include "pyside2_qtlocation_python.h"

// main header
#include "qplaceproposedsearchresult_wrapper.h"

// inner classes

#include <cctype>
#include <cstring>



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QPlaceProposedSearchResultWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPlaceProposedSearchResultWrapper::QPlaceProposedSearchResultWrapper() : QPlaceProposedSearchResult()
{
    resetPyMethodCache();
    // ... middle
}

QPlaceProposedSearchResultWrapper::QPlaceProposedSearchResultWrapper(const QPlaceSearchResult & other) : QPlaceProposedSearchResult(other)
{
    resetPyMethodCache();
    // ... middle
}

QPlaceProposedSearchResultWrapper::~QPlaceProposedSearchResultWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceProposedSearchResult_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceProposedSearchResult >()))
        return -1;

    ::QPlaceProposedSearchResultWrapper *cptr{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtLocation.QPlaceProposedSearchResult.__init__";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPlaceProposedSearchResult", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QPlaceProposedSearchResult::QPlaceProposedSearchResult()
    // 1: QPlaceProposedSearchResult::QPlaceProposedSearchResult(QPlaceSearchResult)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceProposedSearchResult()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHRESULT_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceProposedSearchResult(QPlaceSearchResult)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPlaceProposedSearchResult_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceProposedSearchResult()
        {

            if (!PyErr_Occurred()) {
                // QPlaceProposedSearchResult()
                cptr = new ::QPlaceProposedSearchResultWrapper();
            }
            break;
        }
        case 1: // QPlaceProposedSearchResult(const QPlaceSearchResult & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceSearchResult *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // QPlaceProposedSearchResult(QPlaceSearchResult)
                cptr = new ::QPlaceProposedSearchResultWrapper(*cppArg0);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceProposedSearchResult >(), cptr)) {
        delete cptr;
        Py_XDECREF(errInfo);
        return -1;
    }
    if (!cptr) goto Sbk_QPlaceProposedSearchResult_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPlaceProposedSearchResult_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, fullName, errInfo);
        Py_XDECREF(errInfo);
        return -1;
}

static PyObject *Sbk_QPlaceProposedSearchResultFunc_searchRequest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QPlaceProposedSearchResult *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtLocationTypes[SBK_QPLACEPROPOSEDSEARCHRESULT_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtLocation.QPlaceProposedSearchResult.searchRequest";
    SBK_UNUSED(fullName)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // searchRequest()const
            QPlaceSearchRequest* cppResult = new QPlaceSearchRequest(const_cast<const ::QPlaceProposedSearchResult *>(cppSelf)->searchRequest());
            pyResult = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHREQUEST_IDX]), cppResult, true, true);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceProposedSearchResultFunc_setSearchRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QPlaceProposedSearchResult *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtLocationTypes[SBK_QPLACEPROPOSEDSEARCHRESULT_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *errInfo{};
    SBK_UNUSED(errInfo)
    static const char *fullName = "PySide2.QtLocation.QPlaceProposedSearchResult.setSearchRequest";
    SBK_UNUSED(fullName)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceProposedSearchResult::setSearchRequest(QPlaceSearchRequest)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppReferenceConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHREQUEST_IDX]), (pyArg)))) {
        overloadId = 0; // setSearchRequest(QPlaceSearchRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPlaceProposedSearchResultFunc_setSearchRequest_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceSearchRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setSearchRequest(QPlaceSearchRequest)
            cppSelf->setSearchRequest(*cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QPlaceProposedSearchResultFunc_setSearchRequest_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, fullName, errInfo);
        Py_XDECREF(errInfo);
        return {};
}


static const char *Sbk_QPlaceProposedSearchResult_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceProposedSearchResult_methods[] = {
    {"searchRequest", reinterpret_cast<PyCFunction>(Sbk_QPlaceProposedSearchResultFunc_searchRequest), METH_NOARGS},
    {"setSearchRequest", reinterpret_cast<PyCFunction>(Sbk_QPlaceProposedSearchResultFunc_setSearchRequest), METH_O},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_QPlaceProposedSearchResult_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::QPlaceProposedSearchResult *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtLocationTypes[SBK_QPLACEPROPOSEDSEARCHRESULT_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QPlaceProposedSearchResultWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPlaceProposedSearchResult_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QPlaceProposedSearchResult_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QPlaceProposedSearchResult_Type = nullptr;
static SbkObjectType *Sbk_QPlaceProposedSearchResult_TypeF(void)
{
    return _Sbk_QPlaceProposedSearchResult_Type;
}

static PyType_Slot Sbk_QPlaceProposedSearchResult_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceProposedSearchResult_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceProposedSearchResult_spec = {
    "2:PySide2.QtLocation.QPlaceProposedSearchResult",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceProposedSearchResult_slots
};

} //extern "C"

static void *Sbk_QPlaceProposedSearchResult_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QPlaceSearchResult >()))
        return dynamic_cast< ::QPlaceProposedSearchResult *>(reinterpret_cast< ::QPlaceSearchResult *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceProposedSearchResult_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QPlaceProposedSearchResult_TypeF())))
        return QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceProposedSearchResult_PTR_CppToPython_QPlaceProposedSearchResult(const void *cppIn) {
    auto pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::QPlaceProposedSearchResult *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
    }
    PyObject *result = Shiboken::Object::newObject(Sbk_QPlaceProposedSearchResult_TypeF(), const_cast<void *>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPlaceProposedSearchResult_SignatureStrings[] = {
    "1:PySide2.QtLocation.QPlaceProposedSearchResult(self)",
    "0:PySide2.QtLocation.QPlaceProposedSearchResult(self,other:PySide2.QtLocation.QPlaceSearchResult)",
    "PySide2.QtLocation.QPlaceProposedSearchResult.searchRequest(self)->PySide2.QtLocation.QPlaceSearchRequest",
    "PySide2.QtLocation.QPlaceProposedSearchResult.setSearchRequest(self,request:PySide2.QtLocation.QPlaceSearchRequest)",
    nullptr}; // Sentinel

void init_QPlaceProposedSearchResult(PyObject *module)
{
    _Sbk_QPlaceProposedSearchResult_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceProposedSearchResult",
        "QPlaceProposedSearchResult*",
        &Sbk_QPlaceProposedSearchResult_spec,
        &Shiboken::callCppDestructor< ::QPlaceProposedSearchResult >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHRESULT_IDX]),
        0,
        0    );
    
    auto pyType = reinterpret_cast<PyTypeObject *>(_Sbk_QPlaceProposedSearchResult_Type);
    InitSignatureStrings(pyType, QPlaceProposedSearchResult_SignatureStrings);
    SbkObjectType_SetPropertyStrings(reinterpret_cast<PyTypeObject *>(_Sbk_QPlaceProposedSearchResult_Type), Sbk_QPlaceProposedSearchResult_PropertyStrings);
    SbkPySide2_QtLocationTypes[SBK_QPLACEPROPOSEDSEARCHRESULT_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QPlaceProposedSearchResult_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QPlaceProposedSearchResult_TypeF(),
        QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR,
        is_QPlaceProposedSearchResult_PythonToCpp_QPlaceProposedSearchResult_PTR_Convertible,
        QPlaceProposedSearchResult_PTR_CppToPython_QPlaceProposedSearchResult);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceProposedSearchResult&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceProposedSearchResult).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceProposedSearchResultWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QPlaceProposedSearchResult_TypeF(), &Sbk_QPlaceProposedSearchResult_typeDiscovery);

}
